function y = Basis(x,num,order,knot)
% Evaluates B-Splines basis functions.
%
% x     : Points to evaluate the Basis function at. [vector or matrix].
% num   : Number of the Basis function. Starts at 1.
% order : Order of the B-Spline functions. Cubic Splines are fourth order.
% knot  : Knot sequence to construct the basis functions.
%
% Example
% Evaluate cubic BSplines on the interval [-1,1].
% x = linespace(-1,1,100);
% b = BSplines(sin(linspace(-1,1,10)),4);
% y = Basis(x,1,4,b.knots)
%
% See also BSplines, ConstructKnots

% Copyright 2011 Laurent Hoeltgen <hoeltgman@gmail.com>
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
% MA 02110-1301, USA.

if order <= 1
    y = (knot(num) <= x).*(x < knot(num+1));
    if num == length(knot)-1
        y(x==knot(end)) = 1;
    end
else
    y = w(x,num,order,knot).*BSplines.Basis(x,num,order-1,knot) + ...
        ( 1-w(x,num+1,order,knot) ).*BSplines.Basis(x,num+1,order-1,knot);
end
end

function y = w(x,num,order,knot)
if knot(num+order-1)-knot(num) ~= 0
    y = (x-knot(num))./(knot(num+order-1)-knot(num));
else
    y = zeros(size(x));
end
end