function B = CollocMatrix(obj,t)
% Computes the B-Spline collocation matrix.
% Computes the collocation Matrix to perform the interpolation. If the vector t
% is specified, it will be used to construct the Matrix. Otherwise the knot
% sequence specified in the BSplines object will be used.
%
% Example
% Compute the collocation matrix using cubic B-Splines.
% b = BSplines(sin(linspace(-1,1,10)),4);
% b.CollocMatrix();
%
% See also BSplines, Interpolate, Basis, ConstructKnots

% Copyright 2011, 2012, 2013 Laurent Hoeltgen <hoeltgman@gmail.com>
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
% MA 02110-1301, USA.

% Last revision on: 24.04.2013 09:55

narginchk(1,2);
nargoutchk(0,1);

x = obj.xI;
k = obj.order;

if nargin == 1
    t = obj.knots;
end

M = length(x);
N = BSplines.NumBSplines(k,length(t));

B = zeros(M,N);

for i = 1:N
    B(:,i) = BSplines.Basis(x',i,k,t);
end
end
