function y = DiffBasis(x,num,order,knot,difforder)
% Differentiate B-Splines basis functions.
% Computes the difforder derivative of the num-th B-Spline of order order at x
% with knot sequence knot.
%
% Example
% Evaluate the first derivative of the 2nd B-Spline at x=0.
% b = BSplines(sin(linspace(-1,1,10)),4);
% BSplines.Diffbasis(0,2,4,b.knots,1);
%
% See also BSplines, Basis

% Copyright 2011 Laurent Hoeltgen <hoeltgman@gmail.com>
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
% MA 02110-1301, USA.

assert( order >= 1 );
assert( difforder >= 0 );

if difforder == 0
    y = BSplines.Basis(x,num,order,knot);
else
    if ( abs( knot(num+order-1)-knot(num) )>eps ) && ...
            ( abs(knot(num+order)-knot(num+1))>eps )
        y = (order - 1)*( BSplines.DiffBasis(x,num,order-1,knot,difforder-1)./ ...
            (knot(num+order-1)-knot(num)) - ...
            BSplines.DiffBasis(x,num+1,order-1,knot,difforder-1)./ ...
            (knot(num+order)-knot(num+1)) );
    elseif ( abs( knot(num+order-1)-knot(num) )<=eps ) && ...
            ( abs(knot(num+order)-knot(num+1))>eps )
        y = (order - 1)*( ...
            BSplines.DiffBasis(x,num+1,order-1,knot,difforder-1)./ ...
            (knot(num+order)-knot(num+1)) );
    elseif ( abs( knot(num+order-1)-knot(num) )>eps ) && ...
            ( abs(knot(num+order)-knot(num+1))<=eps )
        y = (order - 1)*( BSplines.DiffBasis(x,num,order-1,knot,difforder-1)./ ...
            (knot(num+order-1)-knot(num)) );
    else
        y = zeros(size(x));
    end
end
end