function number = NumBSplines(order,knots)
% Returns the number of B-Splines that can be constructed.
% Returns the number of B-Splines of order order that one can generate with
% knots knots.
%
% order : the order of the considered B-Splines. [positive integer]
% knots : the number of knots that are available. [positive integer]
% number : the number of B-Splines that can be constructed. [integer]
%
% Example
% Compute the number of BSplines of order 4 with 12 knots.
% BSplines.NumBSplines(4,12)
%
% See also BSplines, NumKnots

% Copyright 2011 Laurent Hoeltgen <hoeltgman@gmail.com>
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
% MA 02110-1301, USA.

assert( isscalar(order)&&isscalar(knots) , 'BSplines:BadVal' , ...
    'Input Parameters must be scalars.');
% With ord + 1 knots we have exactly 1 B-Spline. Every further knot allows us
% to generate one additional basis function.
number = max([0,knots - order]);
end