function knots = NumKnots(order,cond)
% Returns the necessary number of knots to solve the interpolation problem.
% Returns the necessary number of knots that one needs to be able fulfill cond
% conditions when using B-Spline Interpolation of order order.
%
% order : The order of the considered of the considered B-Splines.
% cond : The number of interpolation conditions that one would like to fulfil.
% knots : The number of knots needed to construct a large enough basis.
%
% Example
% Compute the necessary number of knots to be able to fulfill 10 interpolation
% conditions.
% BSplines.NumKnots(4,10)
%
% See also BSplines, NumBSplines

% Copyright 2011 Laurent Hoeltgen <hoeltgman@gmail.com>
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
% MA 02110-1301, USA.

assert( isscalar(order)&&isscalar(cond) , 'BSplines:BadVal', ...
    'Arguments must be integers.');
assert( (order > 0)&&(cond > 0) , 'BSplines:BadVal', ...
    'Arguments must be positive.');
% With degree + 2 knots we have exactly 1 B-Spline. Every further knot allows us
% to generate one additional basis function.
knots = order + cond;
end