function y = NewtonInterpolation(x,xI,yI)
% NewtonInterpolation
% Perform polynomial interpolatin with Newton's approach.
%
% Example
% xI = linspace(-pi,pi,10);
% yI = sin(xI);
% x = linspace(-pi,pi,1000);
% y = NewtonInterpolation(x,xI,yI);
%
% See also LagrangeInterpolation VandermondeInterpolation

% Copyright 2011, 2012, 2013 Laurent Hoeltgen <hoeltgman@gmail.com>
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
% MA 02110-1301, USA.

% Last revision on: 24.04.2013 09:55

narginchk(3,3);
nargoutchk(0,1);
assert(isrow(xI),'Interpolation:BadArg', ...
    'Second argument must be a row vector.');
assert(isrow(yI),'Interpolation:BadArg', ...
    'Third argument must be a row vector.');
assert(length(xI)==length(unique(xI)),'Interpolation:BadArg', ...
    'Data sites must be unique.');
assert(length(xI)==length(yI),'Interpolation:BadArg', ...
    'Dimension mismatch between data sites and sample values.');

d = diag(DivDiffTable(xI,yI));
n = length(d);
y = d(end).*ones(size(x));
for i = n:-1:1
    y = (x - xI(i)).*y + d(i);
end
end
